<?php

namespace Assetdocs\Student\Http\Controllers\Api;

use App\Http\Controllers\Api\AdminController as BaseController;
use Assetdocs\Student\Http\Requests\ClientRequest;
use Assetdocs\Student\Interfaces\ClientRepositoryInterface;
use Assetdocs\Student\Models\Client;

/**
 * Admin API controller class.
 */
class ClientAdminController extends BaseController
{
    /**
     * Initialize client controller.
     *
     * @param type ClientRepositoryInterface $client
     *
     * @return type
     */
    public function __construct(ClientRepositoryInterface $client)
    {
        $this->repository = $client;
        parent::__construct();
    }

    /**
     * Display a list of client.
     *
     * @return json
     */
    public function index(ClientRequest $request)
    {
        $clients  = $this->repository
            ->setPresenter('\\Assetdocs\\Student\\Repositories\\Presenter\\ClientListPresenter')
            ->scopeQuery(function($query){
                return $query->orderBy('id','DESC');
            })->all();
        $clients['code'] = 2000;
        return response()->json($clients) 
                         ->setStatusCode(200, 'INDEX_SUCCESS');

    }

    /**
     * Display client.
     *
     * @param Request $request
     * @param Model   Client
     *
     * @return Json
     */
    public function show(ClientRequest $request, Client $client)
    {
        $client         = $client->presenter();
        $client['code'] = 2001;
        return response()->json($client)
                         ->setStatusCode(200, 'SHOW_SUCCESS');;

    }

    /**
     * Show the form for creating a new client.
     *
     * @param Request $request
     *
     * @return json
     */
    public function create(ClientRequest $request, Client $client)
    {
        $client         = $client->presenter();
        $client['code'] = 2002;
        return response()->json($client)
                         ->setStatusCode(200, 'CREATE_SUCCESS');

    }

    /**
     * Create new client.
     *
     * @param Request $request
     *
     * @return json
     */
    public function store(ClientRequest $request)
    {
        try {
            $attributes             = $request->all();
            $attributes['user_id']  = user_id('admin.api');
            $client          = $this->repository->create($attributes);
            $client          = $client->presenter();
            $client['code']  = 2004;

            return response()->json($client)
                             ->setStatusCode(201, 'STORE_SUCCESS');
        } catch (Exception $e) {
            return response()->json([
                'message'  => $e->getMessage(),
                'code'     => 4004,
            ])->setStatusCode(400, 'STORE_ERROR');
        }
    }

    /**
     * Show client for editing.
     *
     * @param Request $request
     * @param Model   $client
     *
     * @return json
     */
    public function edit(ClientRequest $request, Client $client)
    {
        $client         = $client->presenter();
        $client['code'] = 2003;
        return response()-> json($client)
                        ->setStatusCode(200, 'EDIT_SUCCESS');;
    }

    /**
     * Update the client.
     *
     * @param Request $request
     * @param Model   $client
     *
     * @return json
     */
    public function update(ClientRequest $request, Client $client)
    {
        try {

            $attributes = $request->all();

            $client->update($attributes);
            $client         = $client->presenter();
            $client['code'] = 2005;

            return response()->json($client)
                             ->setStatusCode(201, 'UPDATE_SUCCESS');


        } catch (Exception $e) {

            return response()->json([
                'message'  => $e->getMessage(),
                'code'     => 4005,
            ])->setStatusCode(400, 'UPDATE_ERROR');

        }
    }

    /**
     * Remove the client.
     *
     * @param Request $request
     * @param Model   $client
     *
     * @return json
     */
    public function destroy(ClientRequest $request, Client $client)
    {
        try {
            $t = $client->delete();

            return response()->json([
                'message'  => trans('messages.success.delete', ['Module' => trans('student::client.name')]),
                'code'     => 2006
            ])->setStatusCode(202, 'DESTROY_SUCCESS');

        } catch (Exception $e) {

            return response()->json([
                'message'  => $e->getMessage(),
                'code'     => 4006,
            ])->setStatusCode(400, 'DESTROY_ERROR');
        }
    }
}
