<?php

namespace Assetdocs\Student\Http\Controllers;

use App\Http\Controllers\UserController as BaseController;
use Form;
use Assetdocs\Student\Http\Requests\ClientRequest;
use Assetdocs\Student\Interfaces\ClientRepositoryInterface;
use Assetdocs\Student\Models\Client;

class ClientUserController extends BaseController
{
    /**
     * Initialize client controller.
     *
     * @param type ClientRepositoryInterface $client
     *
     * @return type
     */
    public function __construct(ClientRepositoryInterface $client)
    {
        $this->repository = $client;
        $this->repository
                ->pushCriteria(app('Litepie\Repository\Criteria\RequestCriteria'))
                ->pushCriteria(new \Assetdocs\Student\Repositories\Criteria\ClientUserCriteria());
        parent::__construct();
    }

    /**
     * Display a listing of the resource.
     *
     * @return Response
     */
    public function index(ClientRequest $request)
    {
        $clients = $this->repository->scopeQuery(function($query){
            return $query->orderBy('id','DESC');
        })->paginate();

        $this->theme->prependTitle(trans('student::client.names'));

        return $this->theme->of('student::user.client.index', compact('clients'))->render();
    }

    /**
     * Display the specified resource.
     *
     * @param Request $request
     * @param Client $client
     *
     * @return Response
     */
    public function show(ClientRequest $request, Client $client)
    {
        Form::populate($client);

        return $this->theme->of('student::user.client.show', compact('client'))->render();
    }

    /**
     * Show the form for creating a new resource.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function create(ClientRequest $request)
    {

        $client = $this->repository->newInstance([]);
        Form::populate($client);

        $this->theme->prependTitle(trans('student::client.names'));
        return $this->theme->of('student::user.client.create', compact('client'))->render();
    }

    /**
     * Display the specified resource.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(ClientRequest $request)
    {
        try {
            $attributes = $request->all();
            $attributes['user_id'] = user_id();
            $client = $this->repository->create($attributes);

            return redirect(trans_url('/user/student/client'))
                -> with('message', trans('messages.success.created', ['Module' => trans('student::client.name')]))
                -> with('code', 201);

        } catch (Exception $e) {
            redirect()->back()->withInput()->with('message', $e->getMessage())->with('code', 400);
        }
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param Request $request
     * @param Client $client
     *
     * @return Response
     */
    public function edit(ClientRequest $request, Client $client)
    {

        Form::populate($client);
        $this->theme->prependTitle(trans('student::client.names'));

        return $this->theme->of('student::user.client.edit', compact('client'))->render();
    }

    /**
     * Update the specified resource.
     *
     * @param Request $request
     * @param Client $client
     *
     * @return Response
     */
    public function update(ClientRequest $request, Client $client)
    {
        try {
            $this->repository->update($request->all(), $client->getRouteKey());

            return redirect(trans_url('/user/student/client'))
                ->with('message', trans('messages.success.updated', ['Module' => trans('student::client.name')]))
                ->with('code', 204);

        } catch (Exception $e) {
            redirect()->back()->withInput()->with('message', $e->getMessage())->with('code', 400);
        }
    }

    /**
     * Remove the specified resource.
     *
     * @param int $id
     *
     * @return Response
     */
    public function destroy(ClientRequest $request, Client $client)
    {
        try {
            $this->repository->delete($client->getRouteKey());
            return redirect(trans_url('/user/student/client'))
                ->with('message', trans('messages.success.deleted', ['Module' => trans('student::client.name')]))
                ->with('code', 204);

        } catch (Exception $e) {

            redirect()->back()->withInput()->with('message', $e->getMessage())->with('code', 400);

        }
    }
}
