<?php

namespace Assetdocs\Student\Http\Controllers;
use Litepie\Student\Http\Requests\ClientRequest;
use Litepie\Student\Models\Client;

trait ClientWorkflow {
	
    /**
     * Workflow controller function for client.
     *
     * @param Model   $client
     * @param step    next step for the workflow.
     *
     * @return Response
     */

    public function putWorkflow(ClientRequest $request, Client $client, $step)
    {

        try {

            $client->updateWorkflow($step);

            return response()->json([
                'message'  => trans('messages.success.changed', ['Module' => trans('student::client.name'), 'status' => trans("app.{$step}")]),
                'code'     => 204,
                'redirect' => trans_url('/admin/client/client/' . $client->getRouteKey()),
            ], 201);

        } catch (Exception $e) {

            return response()->json([
                'message'  => $e->getMessage(),
                'code'     => 400,
                'redirect' => trans_url('/admin/client/client/' . $client->getRouteKey()),
            ], 400);

        }

    }

    /**
     * Workflow controller function for client.
     *
     * @param Model   $client
     * @param step    next step for the workflow.
     * @param user    encrypted user id.
     *
     * @return Response
    */

    public function getWorkflow(Client $client, $step, $user)
    {
        try {
            $user_id = decrypt($user);

            Auth::onceUsingId($user_id);

            $client->updateWorkflow($step);

            $data = [
                'message' => trans('messages.success.changed', ['Module' => trans('student::client.name'), 'status' => trans("app.{$step}")]),
                'status'  => 'success',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('student::admin.client.message', $data)->render();

        } catch (ValidationException $e) {

            $data = [
                'message' => '<b>' . $e->getMessage() . '</b> <br /><br />' . implode('<br />', $e->validator->errors()->all()),
                'status'  => 'error',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('student::admin.client.message', $data)->render();

        } catch (Exception $e) {

            $data = [
                'message' => '<b>' . $e->getMessage(). '</b>',
                'status'  => 'error',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('student::admin.client.message', $data)->render();

        }

    }
}