<?php

namespace Assetdocs\Student\Policies;

use Litepie\User\Contracts\UserPolicy;
use Assetdocs\Student\Models\Client;

class ClientPolicy
{

    /**
     * Determine if the given user can view the client.
     *
     * @param UserPolicy $user
     * @param Client $client
     *
     * @return bool
     */
    public function view(UserPolicy $user, Client $client)
    {
        if ($user->canDo('student.client.view') && $user->is('admin')) {
            return true;
        }

        if ($user->canDo('blocks.block.view') 
        && $user->is('manager')
        && $block->user->parent_id == $user->id) {
            return true;
        }

        return $user->id === $client->user_id;
    }

    /**
     * Determine if the given user can create a client.
     *
     * @param UserPolicy $user
     * @param Client $client
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('student.client.create');
    }

    /**
     * Determine if the given user can update the given client.
     *
     * @param UserPolicy $user
     * @param Client $client
     *
     * @return bool
     */
    public function update(UserPolicy $user, Client $client)
    {
        if ($user->canDo('student.client.update') && $user->is('admin')) {
            return true;
        }

        if ($user->canDo('blocks.block.update') 
        && $user->is('manager')
        && $block->user->parent_id == $user->id) {
            return true;
        }

        return $user->id === $client->user_id;
    }

    /**
     * Determine if the given user can delete the given client.
     *
     * @param UserPolicy $user
     * @param Client $client
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Client $client)
    {
        if ($user->canDo('student.client.delete') && $user->is('admin')) {
            return true;
        }

        if ($user->canDo('blocks.block.delete') 
        && $user->is('manager')
        && $block->user->parent_id == $user->id) {
            return true;
        }

        return $user->id === $client->user_id;
    }

    /**
     * Determine if the given user can verify the given client.
     *
     * @param UserPolicy $user
     * @param Client $client
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Client $client)
    {
        if ($user->canDo('student.client.verify') && $user->is('admin')) {
            return true;
        }

        if ($user->canDo('student.client.verify') 
        && $user->is('manager')
        && $client->user->parent_id == $user->id) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given client.
     *
     * @param UserPolicy $user
     * @param Client $client
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Client $client)
    {
        if ($user->canDo('student.client.approve') && $user->is('admin')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperUser()) {
            return true;
        }
    }
}
