<?php

namespace Assetdocs\Student\Providers;

use Illuminate\Support\ServiceProvider;

class StudentServiceProvider extends ServiceProvider
{
    /**
     * Indicates if loading of the provider is deferred.
     *
     * @var bool
     */
    protected $defer = false;

    /**
     * Bootstrap the application events.
     *
     * @return void
     */
    public function boot()
    {
        // Load view
        $this->loadViewsFrom(__DIR__ . '/../../resources/views', 'student');

        // Load translation
        $this->loadTranslationsFrom(__DIR__ . '/../../resources/lang', 'student');

        // Load migrations
        $this->loadMigrationsFrom(__DIR__ . '/../../database/migrations');

        // Call pblish redources function
        $this->publishResources();

    }

    /**
     * Register the service provider.
     *
     * @return void
     */
    public function register()
    {
        // Bind facade
        $this->app->bind('student', function ($app) {
            return $this->app->make('Assetdocs\Student\Student');
        });

                // Bind Client to repository
        $this->app->bind(
            'Assetdocs\Student\Interfaces\ClientRepositoryInterface',
            \Assetdocs\Student\Repositories\Eloquent\ClientRepository::class
        );

        $this->app->register(\Assetdocs\Student\Providers\AuthServiceProvider::class);
                $this->app->register(\Assetdocs\Student\Providers\EventServiceProvider::class);
        
        $this->app->register(\Assetdocs\Student\Providers\RouteServiceProvider::class);
                $this->app->register(\Assetdocs\Student\Providers\WorkflowServiceProvider::class);
                
    }

    /**
     * Get the services provided by the provider.
     *
     * @return array
     */
    public function provides()
    {
        return ['student'];
    }

    /**
     * Publish resources.
     *
     * @return void
     */
    private function publishResources()
    {
        // Publish configuration file
        $this->publishes([__DIR__ . '/../../config/config.php' => config_path('assetdocs/student.php')], 'config');

        // Publish admin view
        $this->publishes([__DIR__ . '/../../resources/views' => base_path('resources/views/vendor/student')], 'view');

        // Publish language files
        $this->publishes([__DIR__ . '/../../resources/lang' => base_path('resources/lang/vendor/student')], 'lang');

        // Publish public files and assets.
        $this->publishes([__DIR__ . '/public/' => public_path('/')], 'public');
    }
}
