<?php

namespace Assetdocs\Student\Workflow;

use Exception;
use Litepie\Workflow\Exceptions\WorkflowActionNotPerformedException;

use Assetdocs\Student\Models\Client;

class ClientAction
{
    /**
     * Perform the complete action.
     *
     * @param Client $client
     *
     * @return Client
     */
    public function complete(Client $client)
    {
        try {
            $client->status = 'complete';
            return $client->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the verify action.
     *
     * @param Client $client
     *
     * @return Client
     */public function verify(Client $client)
    {
        try {
            $client->status = 'verify';
            return $client->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the approve action.
     *
     * @param Client $client
     *
     * @return Client
     */public function approve(Client $client)
    {
        try {
            $client->status = 'approve';
            return $client->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the publish action.
     *
     * @param Client $client
     *
     * @return Client
     */public function publish(Client $client)
    {
        try {
            $client->status = 'publish';
            return $client->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the archive action.
     *
     * @param Client $client
     *
     * @return Client
     */
    public function archive(Client $client)
    {
        try {
            $client->status = 'archive';
            return $client->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the unpublish action.
     *
     * @param Client $client
     *
     * @return Client
     */
    public function unpublish(Client $client)
    {
        try {
            $client->status = 'unpublish';
            return $client->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }
}
