<?php

namespace Assetdocs\Student\Workflow;

use Assetdocs\Student\Models\Client;
use Validator;

class ClientValidator
{

    /**
     * Determine if the given client is valid for complete status.
     *
     * @param Client $client
     *
     * @return bool / Validator
     */
    public function complete(Client $client)
    {
        return Validator::make($client->toArray(), [
            'title' => 'required|min:15',
        ]);
    }

    /**
     * Determine if the given client is valid for verify status.
     *
     * @param Client $client
     *
     * @return bool / Validator
     */
    public function verify(Client $client)
    {
        return Validator::make($client->toArray(), [
            'title'  => 'required|min:15',
            'status' => 'in:complete',
        ]);
    }

    /**
     * Determine if the given client is valid for approve status.
     *
     * @param Client $client
     *
     * @return bool / Validator
     */
    public function approve(Client $client)
    {
        return Validator::make($client->toArray(), [
            'title'  => 'required|min:15',
            'status' => 'in:verify',
        ]);

    }

    /**
     * Determine if the given client is valid for publish status.
     *
     * @param Client $client
     *
     * @return bool / Validator
     */
    public function publish(Client $client)
    {
        return Validator::make($client->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:approve,archive,unpublish',
        ]);

    }

    /**
     * Determine if the given client is valid for archive status.
     *
     * @param Client $client
     *
     * @return bool / Validator
     */
    public function archive(Client $client)
    {
        return Validator::make($client->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:approve,publish,unpublish',
        ]);

    }

    /**
     * Determine if the given client is valid for unpublish status.
     *
     * @param Client $client
     *
     * @return bool / Validator
     */
    public function unpublish(Client $client)
    {
        return Validator::make($client->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:publish',
        ]);

    }
}
